"""
软件名称:星门数据库(stargateDB)
描述：星门数据库是一款微型电脑数据库
官方首页：http://www.stargatedb.com/
文档教程：http://www.stargatedb.com/index.php/wendangjiaocheng.html
申请账号：http://www.stargatedb.com/index.php/page/user.html
作者：重庆羊排信息技术有限公司
发布日期：2021年4月1日
"""
from . import cloud,user