#!/usr/bin/env python
# -*- coding:utf-8

#----ai文字识别配置
'''words默认主目录设置'''
_words_path = "E:\\pool\\"

#----ai图像识别配置
'''image默认主目录设置'''
_image_path = "E:\\pool\\"

#----ai语音识别配置
'''speech默认主目录设置'''
_speech_path = "E:\\pool\\"

#----files文件操作配置
'''files默认主目录设置'''
_files_path = "E:\\pool\\"