#!/usr/bin/env python
# -*- coding:utf-8

"""
软件名称:星门数据库(stargateDB)
描述：星门数据库是一款微型电脑云数据库
官方首页：http://www.stargatedb.com/
文档教程：http://www.stargatedb.com/index.php/wendangjiaocheng.html
申请账号：http://www.stargatedb.com/index.php/page/user.html
作者：重庆羊排信息技术有限公司
发布日期：2021年4月1日
"""

# -----示列代码-----

# import stargatedb.cloud as cloud

# 添加字符数据
# res=Add("wumeng","xxxxx","xxxxx","无梦","new",30)
# print(res)

# 修改字符数据
# res=Change("xxxxx","xxxxx","new",10)
# print(res)

# 删除字符数据
# res=Delete("xxxxx","xxxxx")
# print(res)

# 查找字符数据
# res=AllFind("xxxxx","xxxxx","new")
# for i in res:
#     print(res[i]['value'])

# 添加音频数据
# res=AddAudio("xxxxx","xxxxx","1.mp3","new","./new/")
# print(res)

# 查找音频数据
# res=FindAudio("xxxxx","xxxxx","1.mp3","new","./test/")
# print(res)

# 删除音频数据
# res=DeleteAudio("xxxxx","xxxxx","1.mp3","new")
# print(res)

