#!/usr/bin/env python
# -*- coding:utf-8
# import sys
# from . import data
# try:
#     data.Client()
# except:
#     print( "redis未连接，请先连接redis" )
#     sys.exit(0)

#初始化控制器
from . import mouse,image,keyboard,words,input,config,window,time,files,view,machineVision,machineSpeech,user

# #初始化libs库
# from stargate.libs import autogui as autogui
# from stargate.libs import extend as extend
# from stargate.libs import baidu as baidu
# from stargate.libs import common as common
# from stargate.libs import redis as redis
# from stargate.libs import opencv as opencv
#
# _autogui=autogui.Autogui()
# _extend=extend.Extend()
# _baidu=baidu.Baidu()
# _redis=redis.Redis()
# _opencv=opencv.Opencv()
# _common=common
