import setuptools
setuptools.setup(
    name="pystargate", # Replace with your own username
    version="1.0.3",
    author="yangpai",
    author_email="wumeng@mail.yangpai.co",
    description="pyStargate engine is an open source (IPA) intelligent process automation development framework",
    long_description="pyStargate engine is an open source (IPA) intelligent process automation development framework",
    long_description_content_type="text/markdown",
    url="http://www.pystargate.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.7'
)
